@@ -14,12 +14,15 @@
 import json
 import logging
 import functools
+from multiprocessing.dummy import Array
 import re
 from types import FunctionType
+from rest_framework.response import Response
 from TDhelper.generic.classDocCfg import doc
 from TDhelper.generic.dictHelper import createDictbyStr, findInDict
 from TDhelper.network.http.REST_HTTP import GET, POST, PUT, DELETE, serializePostData
 from TDhelper.generic.requier import R, InstanceCall
+from TDhelper.generic.randGetValue import getValue
 # code start
 
 
@@ -31,6 +34,7 @@ class Event:
     '''
 
     def __init__(self, event_uri, platformKey: str, secret=None, httpHeaders={}):
+        event_uri= getValue(event_uri)
         self._event_uri = event_uri + \
             ('/' if event_uri.find('/', len(event_uri)-1) <= -1 else '')
         self._platformKey = platformKey
@@ -149,7 +153,7 @@ class Manager:
             -   platformKey:<str>, event platform key index.
             -   RPCInstance:<TDhelper.network.http.RPC>, RPC instace. then trigger handle type is rpc must use it.
         '''
-        self._event_service_uri = service_uri  # 事件服务地址
+        self._event_service_uri = getValue(service_uri)  # 事件服务地址
         self._event_httpHeaders = {}
         self._event_httpHeaders['api-token'] = event_secret if event_secret else ''
         self._event_cache = {}  # 事件缓存
@@ -166,9 +170,8 @@ class Manager:
 
     def _getRemoteEventRelation(self):
         if not self._event_cache:
-            if self._event_service_uri.find('/', len(self._event_service_uri)-1) > -1:
-                self._event_service_uri+'/'
-            m_uri = self._event_service_uri + \
+            # 从服务器组里随机取一个地址.
+            m_uri = self._event_service_uri.rstrip("/") +"/" + \
                 "events/?plateform=%s" % self._platform
             try:
                 state, body = GET(
@@ -192,7 +195,7 @@ class Manager:
             @functools.wraps(func)
             def wapper(*args, **kwargs):
                 if eventKey:
-                    _handleName = func.__qualname__.split('.')[0].upper()+'_'+ eventKey.upper()
+                    _handleName = self._platform+"."+ eventKey.upper()
                 else:
                     _handleName = func.__qualname__.replace('.', '_').upper()
                 ret = self.on(_handleName, "BEFORE", *args, **kwargs)
@@ -230,27 +233,13 @@ class Manager:
                         ret = None
                 else:
                     ret = None
+                if isinstance(ret, Response):
+                    ret.data['trigger_results']= kwargs['trigger_results']
+                    return ret
                 return ret, kwargs['trigger_results']
             return wapper
         return decorator
 
-    def _func_returns_mapping(self, mapping: dict, *args, **kwargs):
-        '''
-            {
-                "type":"object|json|indexes",
-                "mapping":[
-                    {"源(self返回本身)","目标"}
-                ]
-            }
-        '''
-        m_args = []
-        for v in args:
-            m_args.append(v)
-        if isinstance(mapping, dict):
-            if 'master_func_results' in kwargs:
-                pass
-        return args, kwargs
-
     def on(self, handle, event, *args, **kwargs):
         if not handle:
             raise Exception('webEvent.on handle is none.')
@@ -312,12 +301,15 @@ class Manager:
             if 'resultType' in checkedConfig:
                 resultType = checkedConfig['resultType'].lower()
                 if resultType == 'json':
-                    if isinstance(result, bytes):
-                        result = str(result, encoding='utf-8')
-                        try:
-                            result = json.loads(result, encoding='utf-8')
-                        except:
-                            result = {}
+                    if isinstance(result, Response):
+                        result= result.data
+                    else:
+                        if isinstance(result, bytes):
+                            result = str(result, encoding='utf-8')
+                            try:
+                                result = json.loads(result, encoding='utf-8')
+                            except:
+                                result = {}
                     if checkedConfig['key'] not in result:
                         return (False, result)
                     else:
@@ -422,7 +414,9 @@ class Manager:
             else:
                 if 'master_func_results' in kwargs:
                     m_func_result= kwargs['master_func_results']
-                    if isinstance(m_func_result,(tuple,[])):
+                    if isinstance(m_func_result, Response):
+                        m_func_result= m_func_result.data
+                    if isinstance(m_func_result,(tuple,list)):
                         # master func results is Indexes type, mapping process
                         if key == 'self':
                             value= m_func_result
@@ -439,9 +433,9 @@ class Manager:
                         if key == 'self':
                             value= m_func_result
                         else:
-                            result_key= key.split('.')
+                            result_key= key.split('.')       
                             if len(result_key)==2:
-                                if int(result_key[1])< len(m_func_result):
+                                if result_key[1] in m_func_result:
                                     value= m_func_result[result_key[1]]
                                 else:
                                     value= None
@@ -505,11 +499,12 @@ class Manager:
             {
                 "param1":{
                     "key":"args.0",
-                    "default": ''
+                    "default": '',
                 },
                 "param2":{
                     "key":"kwargs.t",
-                    "default":''
+                    "default":'',
+                    "sources": true
                 }
             }
         '''
@@ -547,7 +542,7 @@ class Manager:
                     params_ret = self._generic_params(
                         m_params, False, *args, **kwargs)
                     rpc_result = self._RPC[m_service].call(
-                        m_handle, **params_ret)
+                        item['callHandle'], **params_ret)
                     if rpc_result['state'] == 200:
                         return True, rpc_result
                     else:
