@@ -9,14 +9,15 @@ from TDhelper.generic.classDocCfg import doc
 from TDhelper.generic.dictHelper import createDictbyStr, findInDict
 from TDhelper.network.http.REST_HTTP import GET, POST, PUT, DELETE, serializePostData
 from TDhelper.generic.recursion import recursion, recursionCall
-
+from TDhelper.generic.randGetValue import getValue
 
 class register:
     def __init__(self, host, platformKey: str, secret=None, httpHeaders={}):
-        self._host = host
+        self._host = getValue(host).rstrip('/')+"/"
         self._platformKey = platformKey
         self._secret = secret
         self._httpHeaders = httpHeaders
+        self._httpHeaders['api-token']=self._secret
 
     def Register(self, serviceClass=None):
         '''
